==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На цьому сервері вимкнута можливість передавання даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити спільний доступ до об'єднаної хмари, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не вдалося надати %1$s у спільний доступ, оскільки цей ресурс вже надано у спільний доступ користувачеві %2$s",
    "Not allowed to create a federated share to the same account" : "Не дозволяється створювати міжхмарні спільні ресурси для одного й того саме облікового запису",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Спільні хмарні ресурси",
    "Sharing" : "Спільний доступ",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Confirm data upload to lookup server" : "Підтвердіть завантаження даних на сервер пошуку",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Якщо ця опція увімкнена, всі властивості облікового запису (наприклад, адреса електронної пошти) з видимістю, встановленою на «опубліковано», будуть автоматично синхронізовані та передані до зовнішньої системи і стануть доступними в публічній глобальній адресній книзі.",
    "Disable upload" : "Вимкнути завантаження",
    "Enable data upload" : "Увімкнути завантаження даних",
    "Confirm querying lookup server" : "Підтвердити запит до сервера пошуку",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Це використовується для отримання ідентифікатора федеративної хмари, щоб спростити федеративне спільне використання.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Крім того, адреси електронної пошти користувачів можуть бути надіслані до цієї системи з метою їх перевірки.",
    "Disable querying" : "Вимкнути запити",
    "Enable querying" : "Увімкнути запити",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Налаштуйте, як користувчі можуть надавати у спільний доступ ресурси користувачам інших серверів хмар. Це включає в себе надання у спільний доступ ресурсів користувачів як цього серверу, так і об'єднаних хмар.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам цієї хмари надавати ресурси у спільний доступ користувачам інших серверів хмар (цей параметр дозволить доступ через протокол WebDAV до публічних спільних ресурсів)",
    "Allow people on this server to receive shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів користувачів з інших серверів хмар",
    "Allow people on this server to send shares to groups on other servers" : "Дозволити користувачам цієї хмари надавати у спільний доступ ресурси групам користувачів інших хмарних серверів",
    "Allow people on this server to receive group shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів груп користувачів інших хмарних серверів",
    "The lookup server is only available for global scale." : "Сервер пошуку доступний тільки для глобального масштабу.",
    "Search global and public address book for people" : "Шукати користувачів у глобальній та публічній адресних книгах",
    "Allow people to publish their data to a global and public address book" : "Дозволити користувачам розміщувати власні дані у глобальній публічній адресній книзі",
    "Trusted federation" : "Довірена федерація",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Автоматично приймати акції від надійних федеративних облікових записів та груп за замовчуванням",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділіться зі мною через мій #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "Cloud ID copied" : "Хмарний ідентифікатор скопійовано",
    "Copy" : "Копіювати",
    "Clipboard not available. Please copy the cloud ID manually." : "Буфер обміну недоступний. Будь ласка, скопіюйте ідентифікатор хмари вручну.",
    "Copied!" : "Скопійовано!",
    "Federated Cloud" : "Об'єднана хмара",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "Your Federated Cloud ID" : "Ваш ідентифікатор Federated Cloud",
    "Share it so your friends can share files with you:" : "Поділіться ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (раніше відома як Twitter)",
    "formerly Twitter" : "раніше відома як Twitter",
    "Mastodon" : "Мастодонт",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Додати на ваш вебсайт",
    "HTML Code:" : "Код HTML:",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Remote share" : "Віддалений каталог",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share password" : "Пароль для віддаленого каталогу",
    "Incoming share could not be processed" : "Неможливо обробити вхідну частку",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Копіювати до буферу обміну"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/uk.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "Неправильний Об'єднаний Хмарний Ідентіфікатор ",
    "Server to server sharing is not enabled on this server" : "На цьому сервері вимкнута можливість передавання даних між серверами",
    "Couldn't establish a federated share." : "Не вдалося встановити об’єднаний спільний доступ.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Не вдалося встановити спільний доступ до об'єднаної хмари, можливо, пароль неправильний.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запит на Federated Share надіслано, ви отримаєте запрошення. Перевірте сповіщення.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не вдалося встановити об’єднаний ресурс, схоже, сервер, з яким потрібно об’єднатися, застарий (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Заборонено надсилати об’єднані спільні групи з цього сервера.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не вдалося надати %1$s у спільний доступ, оскільки цей ресурс вже надано у спільний доступ користувачеві %2$s",
    "Not allowed to create a federated share to the same account" : "Не дозволяється створювати міжхмарні спільні ресурси для одного й того саме облікового запису",
    "Federated shares require read permissions" : "Об’єднані спільні ресурси потребують дозволу на читання",
    "File is already shared with %s" : "Файл вже в загальному доступі з %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Помилка спільного доступу %1$s, не вдалося знайти %2$s, можливо, сервер наразі недоступний або використовує самопідписаний сертифікат.",
    "Could not find share" : "Не вдалося знайти спільний доступ",
    "Federated sharing" : "Об'єднаний спільний доступ",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Ви отримали {share} як віддалений спільний доступ від {user} (від імені {behalf})",
    "You received {share} as a remote share from {user}" : "Ви отримали {share} як віддалений спільний доступ від {user}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "Federated Cloud Sharing" : "Спільні хмарні ресурси",
    "Sharing" : "Спільний доступ",
    "Federated file sharing" : "Інтегрований обмін файлами",
    "Provide federated file sharing across servers" : "Забезпечте об’єднаний обмін файлами між серверами",
    "Confirm data upload to lookup server" : "Підтвердіть завантаження даних на сервер пошуку",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Якщо ця опція увімкнена, всі властивості облікового запису (наприклад, адреса електронної пошти) з видимістю, встановленою на «опубліковано», будуть автоматично синхронізовані та передані до зовнішньої системи і стануть доступними в публічній глобальній адресній книзі.",
    "Enable data upload" : "Увімкнути завантаження даних",
    "Disable upload" : "Вимкнути завантаження",
    "Confirm querying lookup server" : "Підтвердити запит до сервера пошуку",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Це використовується для отримання ідентифікатора об'єднаної хмари, щоб спростити спільне використання ресурсів.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Крім того, адреси електронної пошти користувачів можуть бути надіслані до цієї системи з метою їх перевірки.",
    "Enable querying" : "Увімкнути запити",
    "Disable querying" : "Вимкнути запити",
    "Unable to update federated files sharing config" : "Неможливо оновити конфігурацію спільного доступу до об’єднаних файлів",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Налаштуйте, як користувчі можуть надавати у спільний доступ ресурси користувачам інших серверів хмар. Це включає в себе надання у спільний доступ ресурсів користувачів як цього сервера, так і сервера об'єднаних хмар.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволити користувачам цієї хмари надавати ресурси у спільний доступ користувачам інших серверів хмар (цей параметр дозволить доступ через протокол WebDAV до публічних спільних ресурсів)",
    "Allow people on this server to receive shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів користувачів з інших серверів хмар",
    "Allow people on this server to send shares to groups on other servers" : "Дозволити користувачам цієї хмари надавати у спільний доступ ресурси групам користувачів інших хмарних серверів",
    "Allow people on this server to receive group shares from other servers" : "Дозволити користувачам цієї хмари отримувати доступ до спільних ресурсів груп користувачів інших хмарних серверів",
    "The lookup server is only available for global scale." : "Сервер пошуку доступний тільки для глобального масштабу.",
    "Search global and public address book for people" : "Шукати користувачів у глобальній та публічній адресних книгах",
    "Allow people to publish their data to a global and public address book" : "Дозволити користувачам розміщувати власні дані у глобальній публічній адресній книзі",
    "Trusted federation" : "Довірена федерація",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Типово автоматично приймати пропозиції спільного доступу від надійних облікових записів та груп об'єднаних хмар",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Поділітися зі мною через мій #Nextcloud Federated Cloud ID, див. {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Поділітися зі мною через мій #Nextcloud Federated Cloud ID",
    "Share with me via Nextcloud" : "Поділися зі мною через Nextcloud",
    "Cloud ID copied" : "Хмарний ідентифікатор скопійовано",
    "Copy" : "Копіювати",
    "Clipboard not available. Please copy the cloud ID manually." : "Буфер обміну недоступний. Будь ласка, скопіюйте ідентифікатор хмари вручну.",
    "Copied!" : "Скопійовано!",
    "Federated Cloud" : "Об'єднана хмара",
    "Your Federated Cloud ID" : "Ваш ідентифікатор Federated Cloud",
    "Share it so your friends can share files with you:" : "Поділітися ним, щоб ваші друзі могли ділитися з вами файлами:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Мастодонт",
    "Add to your website" : "Додати на ваш вебсайт",
    "HTML Code:" : "Код HTML:",
    "Cancel" : "Скасувати",
    "Add remote share" : "Додати віддалений каталог",
    "Remote share" : "Віддалений каталог",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Додати віддалений каталог {name} з {owner}@{remote}?",
    "Remote share password" : "Пароль для віддаленого каталогу",
    "Incoming share could not be processed" : "Неможливо обробити вхідну частку",
    "Cloud ID copied to the clipboard" : "Cloud ID скопійовано в буфер обміну",
    "Copy to clipboard" : "Копіювати до буфера обміну",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Ви можете поділитися з будь-ким, хто використовує сервер Nextcloud або інші сервери та служби, сумісні з Open Cloud Mesh (OCM). Просто введіть їхній Federated Cloud ID у діалоговому вікні спільного доступу. Це виглядає як person@cloud.example.com",
    "X (formerly Twitter)" : "X (раніше відома як Twitter)",
    "formerly Twitter" : "раніше відома як Twitter"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
